arch_binaries  := $(arch_binaries) libssp
ifeq ($(with_lib64ssp),yes)
  arch_binaries  := $(arch_binaries) lib64ssp
endif
ifeq ($(with_lib32ssp),yes)
  arch_binaries	:= $(arch_binaries) lib32ssp
endif

p_ssp	= libssp$(SSP_SONAME)
p_ssp32	= lib32ssp$(SSP_SONAME)
p_ssp64	= lib64ssp$(SSP_SONAME)
p_sspd	= libssp$(SSP_SONAME)-dev

d_ssp	= debian/$(p_ssp)
d_ssp32	= debian/$(p_ssp32)
d_ssp64	= debian/$(p_ssp64)
d_sspd	= debian/$(p_sspd)

dirs_ssp = \
	$(docdir)/$(p_ssp) \
	$(PF)/$(libdir)
files_ssp = \
	$(PF)/$(libdir)/libssp.so.*

dirs_sspd = \
	$(docdir) \
	$(PF)/include \
	$(PF)/$(libdir)
files_sspd = \
	$(gcc_lib_dir)/include/ssp \
	$(PF)/$(libdir)/libssp.{a,so,la} \
	$(PF)/$(libdir)/libssp_nonshared.{a,la}

ifeq ($(with_lib32ssp),yes)
	dirs_sspd  += $(lib32)
	files_sspd += $(lib32)/libssp.{a,la,so}
	files_sspd += $(lib32)/libssp_nonshared.{a,la}
endif
ifeq ($(with_lib64ssp),yes)
	dirs_sspd  += $(PF)/lib64
	files_sspd += $(PF)/lib64/libssp.{a,la,so}
	files_sspd += $(PF)/lib64/libssp_nonshared.{a,la}
endif

$(binary_stamp)-libssp: $(install_stamp)
	dh_testdir
	dh_testroot
	mv $(install_stamp) $(install_stamp)-tmp

	rm -rf $(d_ssp) $(d_sspd)
	dh_installdirs -p$(p_ssp) $(dirs_ssp)
	dh_installdirs -p$(p_sspd) $(dirs_sspd)

	DH_COMPAT=2 dh_movefiles -p$(p_ssp) $(files_ssp)
	DH_COMPAT=2 dh_movefiles -p$(p_sspd) $(files_sspd)

	dh_installdocs -p$(p_ssp)
	dh_installchangelogs -p$(p_ssp) $(srcdir)/libssp/ChangeLog
	debian/dh_doclink -p$(p_sspd) $(p_ssp)

	debian/dh_rmemptydirs -p$(p_ssp)
	debian/dh_rmemptydirs -p$(p_sspd)

	dh_strip -p$(p_ssp) -p$(p_sspd)
	dh_compress -p$(p_ssp) -p$(p_sspd)
	dh_fixperms -p$(p_ssp) -p$(p_sspd)
	dh_makeshlibs -p$(p_ssp) -V '$(p_ssp) (>= $(DEB_SOVERSION))'
	dh_shlibdeps -p$(p_ssp) -p$(p_sspd)
	dh_gencontrol -p$(p_ssp) -p$(p_sspd) \
		-- -v$(DEB_VERSION) $(common_substvars)
	dh_installdeb -p$(p_ssp) -p$(p_sspd)
	dh_md5sums -p$(p_ssp) -p$(p_sspd)
	dh_builddeb -p$(p_ssp) -p$(p_sspd)

	trap '' 1 2 3 15; touch $@; mv $(install_stamp)-tmp $(install_stamp)

# ----------------------------------------------------------------------
$(binary_stamp)-lib64ssp: $(install_stamp)
	dh_testdir
	dh_testroot
	mv $(install_stamp) $(install_stamp)-tmp

	rm -rf $(d_ssp64)
	dh_installdirs -p$(p_ssp64) \
		$(PF)/lib64
	DH_COMPAT=2 dh_movefiles -p$(p_ssp64) \
		$(PF)/lib64/libssp.so.*

	debian/dh_doclink -p$(p_ssp64) $(p_base)

	dh_strip -p$(p_ssp64)
	dh_compress -p$(p_ssp64)
	dh_fixperms -p$(p_ssp64)
	dh_makeshlibs -p$(p_ssp64) -V '$(p_ssp64) (>= $(DEB_SOVERSION))'
#	dh_shlibdeps -p$(p_ssp64)
	dh_gencontrol -p$(p_ssp64) -- -v$(DEB_VERSION) $(common_substvars)
	dh_installdeb -p$(p_ssp64)
	dh_md5sums -p$(p_ssp64)
	dh_builddeb -p$(p_ssp64)

	trap '' 1 2 3 15; touch $@; mv $(install_stamp)-tmp $(install_stamp)

# ----------------------------------------------------------------------
$(binary_stamp)-lib32ssp: $(install_stamp)
	dh_testdir
	dh_testroot
	mv $(install_stamp) $(install_stamp)-tmp

	rm -rf $(d_ssp32)
	dh_installdirs -p$(p_ssp32) \
		$(lib32)
	DH_COMPAT=2 dh_movefiles -p$(p_ssp32) \
		$(lib32)/libssp.so.*

	debian/dh_doclink -p$(p_ssp32) $(p_base)

	dh_strip -p$(p_ssp32)
	dh_compress -p$(p_ssp32)
	dh_fixperms -p$(p_ssp32)
	dh_makeshlibs -p$(p_ssp32) -V '$(p_ssp32) (>= $(DEB_SOVERSION))'
#	dh_shlibdeps -p$(p_ssp32)
	dh_gencontrol -p$(p_ssp32) -- -v$(DEB_VERSION) $(common_substvars)
	dh_installdeb -p$(p_ssp32)
	dh_md5sums -p$(p_ssp32)
	dh_builddeb -p$(p_ssp32)

	trap '' 1 2 3 15; touch $@; mv $(install_stamp)-tmp $(install_stamp)
